@@ -31,56 +31,27 @@
 
 import os as osys
 import tempfile as tmpf
-from typing import Optional, Protocol, TypeVar
 
 from PySide6.QtCore import QUrl as url_t
 from PySide6.QtWebEngineWidgets import QWebEngineView as widget_t
 from PySide6.QtWidgets import QApplication as application_t
 
-from babelplot.type.base import backend_figure_h, backend_frame_h
 from babelplot.type.figure import figure_t
 
 
-backend_content_h = TypeVar("backend_content_h")
-
-
-class html_p(Protocol):
-    def ContentFromArrangedFrames(
-        self, arranged_frames: list[list[Optional[backend_frame_h]]], /
-    ) -> backend_content_h:
-        ...
-
-    @staticmethod
-    def HTMLofContent(
-        figure: backend_figure_h, content: backend_content_h, *args, **kwargs
-    ) -> str:
-        ...
-
-
-def Show(figure: figure_t | html_p, /) -> None:
+def Show(figure: figure_t, /) -> None:
     """"""
-    arranged_frames: list[list[Optional[backend_frame_h]]]
-    arranged_frames = [figure.shape[1] * [None] for _ in range(figure.shape[0])]
-    for frame, (row, col) in zip(figure.frames, figure.locations):
-        if frame.backend is None:
-            frame_or_plot = [_plt.backend for _plt in frame.plots]
-        else:
-            frame_or_plot = frame.backend
-        arranged_frames[row][col] = frame_or_plot
-
-    content = figure.ContentFromArrangedFrames(figure.backend, arranged_frames)
-    html = figure.HTMLofContent(figure.backend, content)
-
     # The application must be instantiated in the same thread/process as the one running exec()
     if (application := application_t.instance()) is None:
         application = application_t()
-
     widget = widget_t()
+
+    html = figure.AsHTML()
     SetHTMLFromFile = lambda sss: _SetHTMLFromFile(sss, widget, html)
     widget.loadFinished.connect(SetHTMLFromFile)
     widget.setHtml(html)
-    widget.show()
 
+    widget.show()
     application.exec()
 
 
