@@ -36,7 +36,7 @@ import sys as sstm
 from pathlib import Path as path_t
 from types import FunctionType as function_type_t
 from types import ModuleType as module_type_t
-from typing import Dict, Optional, Sequence, Tuple, TypeVar, Union
+from typing import Optional, Sequence, TypeVar
 
 from babelplot.backend.specification.plot import plot_e
 from babelplot.brick.log import LOGGER
@@ -50,13 +50,13 @@ parameter_annotation_h = TypeVar("parameter_annotation_h")
 default_value_h = TypeVar("default_value_h")
 returned_annotation_h = TypeVar("returned_annotation_h")
 
-parameter_wo_name_h = Tuple[parameter_type_t, parameter_annotation_h, default_value_h]
-parameter_w_name_h = Tuple[
+parameter_wo_name_h = tuple[parameter_type_t, parameter_annotation_h, default_value_h]
+parameter_w_name_h = tuple[
     parameter_type_t, parameter_annotation_h, default_value_h, str
 ]
-parameter_h = Union[parameter_wo_name_h, parameter_w_name_h]
-parameters_h = Tuple[parameter_h, ...]
-signature_h = Tuple[parameters_h, returned_annotation_h]
+parameter_h = parameter_wo_name_h | parameter_w_name_h
+parameters_h = tuple[parameter_h, ...]
+signature_h = tuple[parameters_h, returned_annotation_h]
 
 
 def CalledBackendMethods(py_module: py_module_h, target_class: str, /) -> Sequence[str]:
@@ -86,13 +86,13 @@ def CalledBackendMethods(py_module: py_module_h, target_class: str, /) -> Sequen
 
 
 def DefinedBackendMethods(
-    module: Union[py_module_h, module_path_t],
+    module: py_module_h | module_path_t,
     imported: module_type_t,
     target_class: str,
     /,
     *,
     should_keep_empty: bool = False,
-) -> Dict[str, signature_h]:
+) -> dict[str, signature_h]:
     """"""
     output = {}
 
@@ -179,7 +179,7 @@ def SignaturePairIssues(
     return None
 
 
-def CheckBackend(backend: Union[py_module_h, module_path_t], /) -> None:
+def CheckBackend(backend: py_module_h | module_path_t, /) -> None:
     """"""
     backend_path = path_t(backend)
     if backend_path.is_file():
