@@ -78,12 +78,20 @@ def _NewFrame(*_, **__) -> backend_frame_h:
     return None
 
 
-def _AsHTML(figure: figure_t, /) -> str:
+def _AdjustLayout(figure: figure_t, /) -> None:
     """"""
     n_rows, n_cols = figure.shape
     if (n_rows > 1) or (n_cols > 1):
+        title_postfix = ""
+
+        frame_titles = (n_rows * n_cols) * [""]
         arranged_plots = [n_cols * [None] for _ in range(n_rows)]
         for frame, (row, col) in zip(figure.frames, figure.locations):
+            if frame.title is not None:
+                frame_titles[row * n_cols + col] = frame.title
+            for plot in frame.plots:
+                if plot.title is not None:
+                    plot.backend.update(name=plot.title)
             arranged_plots[row][col] = [_plt.backend for _plt in frame.plots]
 
         frame_types = [n_cols * [{}] for _ in range(n_rows)]
@@ -91,21 +99,38 @@ def _AsHTML(figure: figure_t, /) -> str:
             for col, plot_cell in enumerate(plot_row):
                 frame_types[row][col] = {"type": plot_cell[0].type}
 
-        contents = NewMultiAxesFigure(rows=n_rows, cols=n_cols, specs=frame_types)
+        raw_figure = NewMultiAxesFigure(
+            rows=n_rows, cols=n_cols, specs=frame_types, subplot_titles=frame_titles
+        )
         for row, plot_row in enumerate(arranged_plots, start=1):
             for col, plot_cell in enumerate(plot_row, start=1):
                 for plot in plot_cell:
-                    contents.add_trace(plot, row=row, col=col)
+                    raw_figure.add_trace(plot, row=row, col=col)
+        figure.backend = raw_figure
     else:
-        contents = figure.backend
-        for plot in figure.frames[0].plots:
-            contents.add_trace(plot.backend)
+        raw_figure = figure.backend
 
+        frame = figure.frames[0]
+        if frame.title is not None:
+            title_postfix = f" - {frame.title}"
+
+        for plot in frame.plots:
+            raw_plot = plot.backend
+            raw_figure.add_trace(raw_plot)
+            if plot.title is not None:
+                raw_plot.update(name=plot.title)
+
+    if figure.title is not None:
+        raw_figure.update_layout(title_text=figure.title + title_postfix)
+
+
+def _AsHTML(figure: figure_t, /) -> str:
+    """"""
     # Note on include_plotlyjs:
     #     "cdn": works but must be online
     #     True => blank figure if using PySide6.QtWebEngineWidgets.QWebEngineView.setHtml because of html size limit.
     #         See note in babelplot.backend.brick.html.Show
-    return contents.to_html(include_plotlyjs=True)
+    return figure.backend.to_html(include_plotlyjs=True)
 
 
 # noinspection PyTypeChecker
@@ -124,6 +149,7 @@ figure_t: base_figure_t = type(
         "frame_class": frame_t,
         "NewBackendFigure": backend_figure_t,
         "NewBackendFrame": staticmethod(_NewFrame),
+        "AdjustLayout": _AdjustLayout,
         "BackendShow": Show,
         "AsHTML": _AsHTML,
     },
@@ -303,5 +329,5 @@ PLOTS[plot_e.TEXT][2] = _Text3
 
 TRANSLATIONS = {
     "alpha": "opacity",
-    "color_face": "surfacecolor",
+    "color_face": "surface_color",
 }
