@@ -51,16 +51,24 @@ scatter_z = nmpy.random.random(n_scatter_points)
 sizes = 100.0 * nmpy.random.random(n_scatter_points)
 colors = nmpy.random.random((n_scatter_points, 3))
 
-figure = NewBabelPlotFigure(pbe=BACKEND)
+figure = NewBabelPlotFigure(title="Scatter Plots", pbe=BACKEND)
 
 frame = figure.AddFrame(title="SCATTER PLOT 2-D")
-frame.AddPlot("scatter", scatter_x, scatter_y, alpha=0.5)
-frame.AddPlot("text", "First sample", scatter_x[0], scatter_y[0], alpha=0.5)
+frame.AddPlot("scatter", scatter_x, scatter_y, alpha=0.5, title="Samples")
+frame.AddPlot(
+    "text", "First sample", scatter_x[0], scatter_y[0], alpha=0.5, title="Annotation"
+)
 
 frame = figure.AddFrame(title="SCATTER PLOT 3-D", dim="xyz", col=1)
-frame.AddPlot("scatter", scatter_x, scatter_y, scatter_z, alpha=0.5)
+frame.AddPlot("scatter", scatter_x, scatter_y, scatter_z, alpha=0.5, title="Samples")
 frame.AddPlot(
-    "text", "First sample", scatter_x[0], scatter_y[0], scatter_z[0], alpha=0.5
+    "text",
+    "First sample",
+    scatter_x[0],
+    scatter_y[0],
+    scatter_z[0],
+    alpha=0.5,
+    title="Annotation",
 )
 
 # --- Line plots
@@ -71,22 +79,22 @@ polyline_z = scatter_z[:n_vertices]
 polygon_x = scatter_x[:n_vertices]
 polygon_y = scatter_y[:n_vertices]
 
-figure = NewBabelPlotFigure(pbe=BACKEND)
+figure = NewBabelPlotFigure(title="Line Plots", pbe=BACKEND)
 
 frame = figure.AddFrame(title="POLYLINE 2-D")
-frame.AddPlot("polyline", polyline_x, polyline_y)
+frame.AddPlot("polyline", polyline_x, polyline_y, title="Line 2-D")
 # frame.SetProperty("xlim", (0, 1), "ylim", (0, 1), "aspect", "equal")
 
 frame = figure.AddFrame(
     title="POLYLINE 3-D", dim="xyz", azimuth=-60, elevation=18, col=1
 )
-frame.AddPlot("polyline", polyline_x, polyline_y, polyline_z)
+frame.AddPlot("polyline", polyline_x, polyline_y, polyline_z, title="Line 3-D")
 
 frame = figure.AddFrame(title="POLYGON", col=2)
-frame.AddPlot("polygon", polygon_x, polygon_y)
+frame.AddPlot("polygon", polygon_x, polygon_y, title="Polygon")
 # frame.SetProperty("aspect", "equal")
 
-# # --- Arrow fields
+# # --- Arrow plots
 # n_arrows = 80
 # arrows_x = scatter_x[:n_arrows] * nmpy.random.choice((-1.0, 1.0), size=n_arrows)
 # arrows_y = scatter_y[:n_arrows] * nmpy.random.choice((-1.0, 1.0), size=n_arrows)
@@ -107,7 +115,7 @@ volume = nmpy.random.random((side + 40, side + 20, side))
 volume = FilteredWithGaussian(volume, 3)
 elevation = volume[:, :, 0]
 
-figure = NewBabelPlotFigure(pbe=BACKEND)
+figure = NewBabelPlotFigure(title="Image-based Plots", pbe=BACKEND)
 
 frame = figure.AddFrame(title="IMAGE")
 frame.AddPlot("image", elevation)
@@ -125,7 +133,7 @@ frame.AddPlot(
     volume,
     0.85 * nmpy.amax(volume),
     # width_edge=0.5,
-    # color_face="r",
+    color_face="r",
     # color_edge="b",
 )
 
@@ -138,7 +146,7 @@ for y in (-1.0, 1.0):
     vertices.append([0.0, y, 1.0 / nmpy.sqrt(2.0)])
 vertices = nmpy.array(vertices)
 
-figure = NewBabelPlotFigure(pbe=BACKEND)
+figure = NewBabelPlotFigure(title="Mesh Plot", pbe=BACKEND)
 
 frame = figure.AddFrame(title="MESH", dim="xyz", azimuth=-75, elevation=36)
 frame.AddPlot("mesh", triangles, vertices)
@@ -148,18 +156,18 @@ n_counts = 12
 counts = 10.0 * scatter_x[:n_counts]
 bar_colors = colors[:n_counts, :]
 
-figure = NewBabelPlotFigure(pbe=BACKEND)
+figure = NewBabelPlotFigure(title="Count-based Plots", pbe=BACKEND)
 
 frame = figure.AddFrame(title="BAR H")
-frame.AddPlot("barh", counts)
+frame.AddPlot("barh", counts, title="Horizontal")
 # frame.SetProperty("aspect", 0.6)
 
 frame = figure.AddFrame(title="BAR V", col=1)
-frame.AddPlot("barv", tuple(range(1, counts.size + 1)), counts)
+frame.AddPlot("barv", tuple(range(1, counts.size + 1)), counts, title="Vertical")
 # frame.SetProperty("aspect", "equal")
 
 frame = figure.AddFrame(title="PIE", col=2)
-frame.AddPlot("pie", counts)
+frame.AddPlot("pie", counts, title="Round")
 
 # frame = figure.AddFrame(title="BAR 3", dim="xyz", col=3)
 # frame.AddPlot("bar3", 3, 4, counts, color=bar_colors)
