@@ -41,8 +41,8 @@ frame = figure_1.AddFrame(plot_width=400, plot_height=200)
 frame.AddPlot("hbar", y=[2, 4, 6], height=1, left=0, right=[1, 2, 3], color="Cyan")
 
 
-figure_2 = NewBabelPlotFigure(pbe="plotly")
-frame = figure_2.AddFrame()
+figure_2 = NewBabelPlotFigure(title="Plotly Figure", pbe="plotly")
+frame = figure_2.AddFrame(title="Plotly Frame")
 frame.AddPlot(
     plly.Surface,
     contours={
@@ -58,6 +58,7 @@ frame.AddPlot(
         [1, 0, 1, 0, 1],
         [0, 1, 0, 1, 0],
     ],
+    name="Surface",
 )
 
 
